@@ -34,7 +34,9 @@ giftRegions <- function(species,min_size=1000,max_size=100000000000){
   
   if(class(jdata) == "try-error"){
     
-    stop("GIFT database not accessible due to connection issues.")
+    message("GIFT database currently not accessible due to issues with the server.
+         Please try again later.")
+    return(NULL)
     
   }else{
     if(length(jdata)==0){warning(paste0("GIFT does not have checklists for ",
