@@ -16,7 +16,7 @@
 #' sps_sp <- occSpatialPoints(sps_occurrence)
 #' @export
 occSpatialPoints <- function(occ) {
-occ  #create spatial points from GBIF coordinates
+#create spatial points from GBIF coordinates
 sp::coordinates(occ) <- ~decimalLongitude + decimalLatitude
 sp::proj4string(occ) <- CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
 return(occ)
